[gs-cvs] rev 6955 - in trunk/gs: lib src

lpd at ghostscript.com lpd at ghostscript.com
Wed Aug 2 22:10:23 PDT 2006


Author: lpd
Date: 2006-08-02 22:10:23 -0700 (Wed, 02 Aug 2006)
New Revision: 6955

Modified:
   trunk/gs/lib/gs_dps1.ps
   trunk/gs/src/zdict.c
Log:
On Level >=2 systems, makes .undef a synonym for undef rather than vice
versa, to produce Adobe-compatible stack traces on errors.


Modified: trunk/gs/lib/gs_dps1.ps
===================================================================
--- trunk/gs/lib/gs_dps1.ps	2006-08-02 21:38:04 UTC (rev 6954)
+++ trunk/gs/lib/gs_dps1.ps	2006-08-03 05:10:23 UTC (rev 6955)
@@ -134,8 +134,4 @@
    pop
  } bind odef
 
-% ------ Miscellaneous ------ %
-
-/undef /.undef load def
-
 end				% level2dict

Modified: trunk/gs/src/zdict.c
===================================================================
--- trunk/gs/src/zdict.c	2006-08-02 21:38:04 UTC (rev 6954)
+++ trunk/gs/src/zdict.c	2006-08-03 05:10:23 UTC (rev 6955)
@@ -496,12 +496,14 @@
     {"1.knownundef", zknownundef},
     {"2.setmaxlength", zsetmaxlength},
 	/*
 	 * In Level 2, >> is a synonym for .dicttomark.  By giving it its
 	 * own entry, it will not be "eq" to .dicttomark, but that doesn't
 	 * matter, since we're doing this only for the sake of Adobe-
 	 * compatible error stacks.
 	 */
     op_def_begin_level2(),
     {"1>>", zdicttomark},
+    {"2undef", zundef},
     op_def_end(0)
 };
@@ -496,12 +496,14 @@
     {"2.setmaxlength", zsetmaxlength},
 	/*
-	 * In Level 2, >> is a synonym for .dicttomark.  By giving it its
-	 * own entry, it will not be "eq" to .dicttomark, but that doesn't
-	 * matter, since we're doing this only for the sake of Adobe-
-	 * compatible error stacks.
+	 * In Level 2, >> is a synonym for .dicttomark, and undef for
+	 * .undef.  By giving the former their own entries, they will not be
+	 * "eq" to .dicttomark and .undef, but that doesn't matter, since
+	 * we're doing this only for the sake of Adobe- compatible error
+	 * stacks.
 	 */
     op_def_begin_level2(),



More information about the gs-cvs mailing list